/*
 * dctpLprocessPApi.h -- DCCP-TP Lprocess port API private definitions
 *
 * Copyright (C) 2008 Tom Phelan
 *
 * This file is part of dccp-tp.
 *
 * Dccp-tp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * Dccp-tp is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with dccp-tp.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Documentation and source code for dccp-tp is available at
 * http://www.phelan-4.com/dccp-tp/.
 */

#ifndef _DCTPLPROCESSPAPI_H_
#define _DCTPLPROCESSPAPI_H_

#define DCTPLP_SOCKDIRNAME   "/tmp/dccp-tp"
#define DCTPLP_CMDSOCKNAME   "/tmp/dccp-tp/dccp-tp-cmd.sck"
#define DCTPLP_RSPSOCKNAME   "/tmp/dccp-tp/dccp-tp-rsp-%u.sck"

#define DCTPLP_OPENCMD       0
#define DCTPLP_CLOSECMD      1
#define DCTPLP_BINDCMD       2
#define DCTPLP_LISTENCMD     3
#define DCTPLP_CONNECTCMD    4
#define DCTPLP_ACCEPTCMD     5
#define DCTPLP_SENDCMD       6
#define DCTPLP_RCVCMD        7
#define DCTPLP_SETOPTCMD     8
#define DCTPLP_NUMCMDS       9

#define DCTPLP_ACKRSP        0
#define DCTPLP_NACKRSP       1

#define DCTPLP_MAXPKTSIZE    1472

typedef struct _dctpLpGenCmd {
    pid_t pid;
    int cmd;
    int sd;
} dctpLpGenCmd;

typedef struct _dctpLpSocketCmd {
    pid_t pid;
    int cmd;
    int sd;
    int domain;
    int type;
    uint32_t scode;
} dctpLpSocketCmd;

typedef struct _dctpLpBindCmd {
    pid_t pid;
    int cmd;
    int sd;
    dctpSockaddr addr;
} dctpLpBindCmd;

typedef struct _dctpLpListenCmd {
    pid_t pid;
    int cmd;
    int sd;
    int backlog;
} dctpLpListenCmd;

typedef struct _dctpLpConnectCmd {
    pid_t pid;
    int cmd;
    int sd;
    dctpSockaddr addr;
} dctpLpConnectCmd;

#define DCTPLP_SETOPTMAX     128

typedef struct _dctpLpSetOptCmd {
    pid_t pid;
    int cmd;
    int sd;
    int optname;
    int optlen;
    int mandatory;
    uint8_t optval[DCTPLP_SETOPTMAX];
} dctpLpSetOptCmd;

typedef struct _dctpLpAckRsp {
    int cmd;
    int rsperrno;
} dctpLpAckRsp;

typedef struct _dctpLpSocketRsp {
    int cmd;
    int rsperrno;
    int sd;
} dctpLpSocketRsp;

typedef struct _dctpLpAcceptRsp {
    int cmd;
    int rsperrno;
    int nsd;
    dctpSockaddr addr;
} dctpLpAcceptRsp;

typedef struct _dctpLpRecvRsp {
    int cmd;
    int rsperrno;
    int mlen;
} dctpLpRecvRsp;

typedef struct _dctpLpCmdThread {
    pid_t pid;
    pthread_t thread;
    pthread_mutex_t mutex;
    pthread_cond_t cond;
    dctpPacket *first;
    dctpPacket *last;
    struct _dctpLpCmdThread *next;
} dctpLpCmdThread;

#endif  /* _DCTPLPROCESSPAPI_H_ */
